@@ -1,36 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -41,6 +42,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Core)
 
 class Q_CORE_EXPORT QPoint
@@ -159,7 +162,6 @@ inline const QPoint operator-(const QPoint &p)
 
 inline QPoint &QPoint::operator/=(qreal c)
 {
-    Q_ASSERT(!qFuzzyCompare(c, 0));
     xp = qRound(xp/c);
     yp = qRound(yp/c);
     return *this;
@@ -167,7 +169,6 @@ inline QPoint &QPoint::operator/=(qreal c)
 
 inline const QPoint operator/(const QPoint &p, qreal c)
 {
-    Q_ASSERT(!qFuzzyCompare(c, 0));
     return QPoint(qRound(p.xp/c), qRound(p.yp/c));
 }
 
@@ -329,7 +330,6 @@ inline const QPointF operator-(const QPointF &p)
 
 inline QPointF &QPointF::operator/=(qreal c)
 {
-    Q_ASSERT(!qFuzzyCompare(c, 0));
     xp/=c;
     yp/=c;
     return *this;
@@ -337,7 +337,6 @@ inline QPointF &QPointF::operator/=(qreal c)
 
 inline const QPointF operator/(const QPointF &p, qreal c)
 {
-    Q_ASSERT(!qFuzzyCompare(c, 0));
     return QPointF(p.xp/c, p.yp/c);
 }
 
@@ -350,6 +349,8 @@ inline QPoint QPointF::toPoint() const
 Q_CORE_EXPORT QDebug operator<<(QDebug d, const QPointF &p);
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QPOINT_H
