@@ -5,17 +5,26 @@
 #  define QT_EDITION QT_EDITION_OPENSOURCE
 #endif
 
-#define QT_BUILD_KEY "macppc OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "amd64 OpenBSD g++-3.* full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define Q_BYTE_ORDER Q_BIG_ENDIAN
+
+#ifdef QT_BOOTSTRAPPED
+#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
+#else
+#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
+#endif
 /* Machine Architecture */
-#define QT_ARCH_GENERIC
+#ifndef QT_BOOTSTRAPPED
+# define QT_ARCH_X86_64
+#else
+# define QT_ARCH_X86_64
+#endif
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
+#define QT_POINTER_SIZE 8
 
 #if defined(QT_BUILTIN_GIF_READER) && defined(QT_NO_BUILTIN_GIF_READER)
 # undef QT_BUILTIN_GIF_READER
@@ -29,10 +38,10 @@
 # define QT_NO_CLOCK_MONOTONIC
 #endif
 
-#if defined(QT_NO_EXCEPTIONS) && defined(QT_EXCEPTIONS)
-# undef QT_NO_EXCEPTIONS
-#elif !defined(QT_NO_EXCEPTIONS) && !defined(QT_EXCEPTIONS)
-# define QT_NO_EXCEPTIONS
+#if defined(QT_NO_ICONV) && defined(QT_ICONV)
+# undef QT_NO_ICONV
+#elif !defined(QT_NO_ICONV) && !defined(QT_ICONV)
+# define QT_NO_ICONV
 #endif
 
 #if defined(QT_NO_IMAGEFORMAT_JPEG) && defined(QT_IMAGEFORMAT_JPEG)
@@ -77,12 +86,30 @@
 # define QT_NO_SXE
 #endif
 
+#if defined(QT_NO_WEBKIT) && defined(QT_WEBKIT)
+# undef QT_NO_WEBKIT
+#elif !defined(QT_NO_WEBKIT) && !defined(QT_WEBKIT)
+# define QT_NO_WEBKIT
+#endif
+
 #if defined(QT_NO_ZLIB) && defined(QT_ZLIB)
 # undef QT_NO_ZLIB
 #elif !defined(QT_NO_ZLIB) && !defined(QT_ZLIB)
 # define QT_NO_ZLIB
 #endif
 
+#if defined(QT_RUNTIME_XCURSOR) && defined(QT_NO_RUNTIME_XCURSOR)
+# undef QT_RUNTIME_XCURSOR
+#elif !defined(QT_RUNTIME_XCURSOR) && !defined(QT_NO_RUNTIME_XCURSOR)
+# define QT_RUNTIME_XCURSOR
+#endif
+
+#if defined(QT_RUNTIME_XFIXES) && defined(QT_NO_RUNTIME_XFIXES)
+# undef QT_RUNTIME_XFIXES
+#elif !defined(QT_RUNTIME_XFIXES) && !defined(QT_NO_RUNTIME_XFIXES)
+# define QT_RUNTIME_XFIXES
+#endif
+
 #if defined(QT_USE_MATH_H_FLOATS) && defined(QT_NO_USE_MATH_H_FLOATS)
 # undef QT_USE_MATH_H_FLOATS
 #elif !defined(QT_USE_MATH_H_FLOATS) && !defined(QT_NO_USE_MATH_H_FLOATS)
