@@ -1,56 +1,74 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
-** This file is part of the core module of the Qt Toolkit.
+** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
 **
-** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
-** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** Contact info@trolltech.com if any conditions of this licensing are
-** not clear to you.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
 #ifndef QLIST_H
 #define QLIST_H
 
-#include "QtCore/qiterator.h"
-#include "QtCore/qatomic.h"
-#include "QtCore/qalgorithms.h"
+#include <QtCore/qiterator.h>
+#include <QtCore/qatomic.h>
+#include <QtCore/qalgorithms.h>
 
 #ifndef QT_NO_STL
 #include <iterator>
 #include <list>
 #endif
 
+#include <new>
+
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
+
+QT_MODULE(Core)
+
 template <typename T> class QVector;
 template <typename T> class QSet;
 
 struct Q_CORE_EXPORT QListData {
     struct Data {
-        QBasicAtomic ref;
+        QBasicAtomicInt ref;
         int alloc, begin, end;
         uint sharable : 1;
         void *array[1];
     };
     enum { DataHeaderSize = sizeof(Data) - sizeof(void *) };
 
-    Data *detach();
+    Data *detach(); // remove in 5.0
+    Data *detach2();
     void realloc(int alloc);
     static Data shared_null;
     Data *d;
@@ -86,11 +104,11 @@ class QList
 
 public:
     inline QList() : d(&QListData::shared_null) { d->ref.ref(); }
-    inline QList(const QList &l) : d(l.d) { d->ref.ref(); if (!d->sharable) detach_helper(); }
+    inline QList(const QList<T> &l) : d(l.d) { d->ref.ref(); if (!d->sharable) detach_helper(); }
     ~QList();
-    QList &operator=(const QList &l);
-    bool operator==(const QList &l) const;
-    inline bool operator!=(const QList &l) const { return !(*this == l); }
+    QList<T> &operator=(const QList<T> &l);
+    bool operator==(const QList<T> &l) const;
+    inline bool operator!=(const QList<T> &l) const { return !(*this == l); }
 
     inline int size() const { return p.size(); }
 
@@ -112,6 +130,7 @@ public:
     void replace(int i, const T &t);
     void removeAt(int i);
     int removeAll(const T &t);
+    bool removeOne(const T &t);
     T takeAt(int i);
     T takeFirst();
     T takeLast();
@@ -145,18 +164,20 @@ public:
         inline bool operator<=(const iterator& other) const { return i <= other.i; }
         inline bool operator>(const iterator& other) const { return i > other.i; }
         inline bool operator>=(const iterator& other) const { return i >= other.i; }
+#ifndef QT_STRICT_ITERATORS
         inline bool operator==(const const_iterator &o) const
-            { return i == reinterpret_cast<const iterator &>(o).i; }
+            { return i == o.i; }
         inline bool operator!=(const const_iterator &o) const
-            { return i != reinterpret_cast<const iterator &>(o).i; }
+            { return i != o.i; }
         inline bool operator<(const const_iterator& other) const
-            { return i < reinterpret_cast<const iterator &>(other).i; }
+            { return i < other.i; }
         inline bool operator<=(const const_iterator& other) const
-            { return i <= reinterpret_cast<const iterator &>(other).i; }
+            { return i <= other.i; }
         inline bool operator>(const const_iterator& other) const
-            { return i > reinterpret_cast<const iterator &>(other).i; }
+            { return i > other.i; }
         inline bool operator>=(const const_iterator& other) const
-            { return i >= reinterpret_cast<const iterator &>(other).i; }
+            { return i >= other.i; }
+#endif
         inline iterator &operator++() { ++i; return *this; }
         inline iterator operator++(int) { Node *n = i; ++i; return n; }
         inline iterator &operator--() { i--; return *this; }
@@ -175,13 +196,17 @@ public:
         typedef std::random_access_iterator_tag  iterator_category;
         typedef ptrdiff_t difference_type;
         typedef T value_type;
-        typedef T *pointer;
-        typedef T &reference;
+        typedef const T *pointer;
+        typedef const T &reference;
 
         inline const_iterator() : i(0) {}
         inline const_iterator(Node *n) : i(n) {}
         inline const_iterator(const const_iterator &o): i(o.i) {}
+#ifdef QT_STRICT_ITERATORS
+        inline explicit const_iterator(const iterator &o): i(o.i) {}
+#else
         inline const_iterator(const iterator &o): i(o.i) {}
+#endif
         inline const T &operator*() const { return i->t(); }
         inline const T *operator->() const { return &i->t(); }
         inline const T &operator[](int j) const { return i[j].t(); }
@@ -196,7 +221,7 @@ public:
         inline const_iterator &operator--() { i--; return *this; }
         inline const_iterator operator--(int) { Node *n = i; i--; return n; }
         inline const_iterator &operator+=(int j) { i+=j; return *this; }
-        inline const_iterator &operator-=(int j) { i+=j; return *this; }
+        inline const_iterator &operator-=(int j) { i-=j; return *this; }
         inline const_iterator operator+(int j) const { return const_iterator(i+j); }
         inline const_iterator operator-(int j) const { return const_iterator(i-j); }
         inline int operator-(const_iterator j) const { return i - j.i; }
@@ -245,6 +270,7 @@ public:
     typedef const value_type *const_pointer;
     typedef value_type &reference;
     typedef const value_type &const_reference;
+    typedef ptrdiff_t difference_type;
 
 #ifdef QT3_SUPPORT
     inline QT3_SUPPORT iterator remove(iterator pos) { return erase(pos); }
@@ -261,14 +287,14 @@ public:
 #endif
 
     // comfort
-    QList &operator+=(const QList &l);
-    inline QList operator+(const QList &l) const
+    QList<T> &operator+=(const QList<T> &l);
+    inline QList<T> operator+(const QList<T> &l) const
     { QList n = *this; n += l; return n; }
-    inline QList &operator+=(const T &t)
+    inline QList<T> &operator+=(const T &t)
     { append(t); return *this; }
-    inline QList &operator<< (const T &t)
+    inline QList<T> &operator<< (const T &t)
     { append(t); return *this; }
-    inline QList &operator<<(const QList &l)
+    inline QList<T> &operator<<(const QList<T> &l)
     { *this += l; return *this; }
 
     QVector<T> toVector() const;
@@ -339,11 +365,10 @@ template <typename T>
 Q_INLINE_TEMPLATE QList<T> &QList<T>::operator=(const QList<T> &l)
 {
     if (d != l.d) {
-        QListData::Data *x = l.d;
-        x->ref.ref();
-        x = qAtomicSetPtr(&d, x);
-        if (!x->ref.deref())
-            free(x);
+        l.d->ref.ref();
+        if (!d->ref.deref())
+            free(d);
+        d = l.d;
         if (!d->sharable)
             detach_helper();
     }
@@ -386,7 +411,7 @@ inline T QList<T>::takeLast()
 { T t = last(); removeLast(); return t; }
 
 template <typename T>
-void QList<T>::append(const T &t)
+Q_OUTOFLINE_TEMPLATE void QList<T>::append(const T &t)
 {
     detach();
     if (QTypeInfo<T>::isLarge || QTypeInfo<T>::isStatic) {
@@ -477,6 +502,7 @@ Q_OUTOFLINE_TEMPLATE T QList<T>::value(int i) const
     }
     return reinterpret_cast<Node *>(p.at(i))->t();
 }
+
 template<typename T>
 Q_OUTOFLINE_TEMPLATE T QList<T>::value(int i, const T& defaultValue) const
 {
@@ -487,21 +513,17 @@ template <typename T>
 Q_OUTOFLINE_TEMPLATE void QList<T>::detach_helper()
 {
     Node *n = reinterpret_cast<Node *>(p.begin());
-    QListData::Data *x = p.detach();
-    if (x)
-        free(x);
+    QListData::Data *x = p.detach2();
     node_copy(reinterpret_cast<Node *>(p.begin()), reinterpret_cast<Node *>(p.end()), n);
+    if (!x->ref.deref())
+        free(x);
 }
 
 template <typename T>
 Q_OUTOFLINE_TEMPLATE QList<T>::~QList()
 {
-    if (!d)
-        return;
-    QListData::Data *x = &QListData::shared_null;
-    x = qAtomicSetPtr(&d, x);
-    if (!x->ref.deref())
-        free(x);
+    if (d && !d->ref.deref())
+        free(d);
 }
 
 template <typename T>
@@ -522,7 +544,7 @@ Q_OUTOFLINE_TEMPLATE bool QList<T>::operator==(const QList<T> &l) const
     return true;
 }
 
-
+// ### Qt 5: rename freeData() to avoid confusion with std::free()
 template <typename T>
 Q_OUTOFLINE_TEMPLATE void QList<T>::free(QListData::Data *data)
 {
@@ -557,6 +579,18 @@ Q_OUTOFLINE_TEMPLATE int QList<T>::removeAll(const T &_t)
     return removedCount;
 }
 
+template <typename T>
+Q_OUTOFLINE_TEMPLATE bool QList<T>::removeOne(const T &_t)
+{
+    detach();
+    int index = indexOf(_t);
+    if (index != -1) {
+        removeAt(index);
+        return true;
+    }
+    return false;
+}
+
 template <typename T>
 Q_OUTOFLINE_TEMPLATE typename QList<T>::iterator QList<T>::erase(typename QList<T>::iterator afirst,
                                                                  typename QList<T>::iterator alast)
@@ -636,4 +670,8 @@ Q_OUTOFLINE_TEMPLATE int QList<T>::count(const T &t) const
 Q_DECLARE_SEQUENTIAL_ITERATOR(List)
 Q_DECLARE_MUTABLE_SEQUENTIAL_ITERATOR(List)
 
+QT_END_NAMESPACE
+
+QT_END_HEADER
+
 #endif // QLIST_H
