@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -26,6 +40,10 @@
 
 #include <QtGui/qwidget.h>
 
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 class QPushButton;
@@ -34,17 +52,16 @@ class QDialogPrivate;
 class Q_GUI_EXPORT QDialog : public QWidget
 {
     Q_OBJECT
-    Q_DECLARE_PRIVATE(QDialog)
     friend class QPushButton;
 
     Q_PROPERTY(bool sizeGripEnabled READ isSizeGripEnabled WRITE setSizeGripEnabled)
     Q_PROPERTY(bool modal READ isModal WRITE setModal)
 
 public:
-    explicit QDialog(QWidget *parent = 0, Qt::WFlags f = 0);
+    explicit QDialog(QWidget *parent = 0, Qt::WindowFlags f = 0);
 #ifdef QT3_SUPPORT
     QT3_SUPPORT_CONSTRUCTOR QDialog(QWidget *parent, const char *name, bool modal = false,
-                                  Qt::WFlags f = 0);
+                                  Qt::WindowFlags f = 0);
 #endif
     ~QDialog();
 
@@ -67,10 +84,6 @@ public:
     bool isSizeGripEnabled() const;
 
     void setModal(bool modal);
-#ifdef Q_OS_TEMP
-    bool event(QEvent *);
-#endif
-
     void setResult(int r);
 
 Q_SIGNALS:
@@ -87,18 +100,32 @@ public Q_SLOTS:
     void showExtension(bool);
 
 protected:
-    QDialog(QDialogPrivate &, QWidget *parent, Qt::WFlags f = 0);
+    QDialog(QDialogPrivate &, QWidget *parent, Qt::WindowFlags f = 0);
 
+#ifdef Q_OS_WINCE
+    bool event(QEvent *e);
+#endif
     void keyPressEvent(QKeyEvent *);
     void closeEvent(QCloseEvent *);
     void showEvent(QShowEvent *);
     void resizeEvent(QResizeEvent *);
+#ifndef QT_NO_CONTEXTMENU
     void contextMenuEvent(QContextMenuEvent *);
+#endif
     bool eventFilter(QObject *, QEvent *);
     void adjustPosition(QWidget*);
 
 private:
+    Q_DECLARE_PRIVATE(QDialog)
     Q_DISABLE_COPY(QDialog)
+
+#ifdef Q_OS_WINCE_WM
+    Q_PRIVATE_SLOT(d_func(), void _q_doneAction())
+#endif
 };
 
+QT_END_NAMESPACE
+
+QT_END_HEADER
+
 #endif // QDIALOG_H
